@@ -37,7 +37,7 @@ use strict;
 ##==============================================================================
 ## Globals & Constants
 
-our $VERSION = "0.08.001";
+our $VERSION = "0.08.002";
 our @ISA = qw(DiaColloDB::Client);
 
 ## $PGOOD_DEFAULT
@@ -68,7 +68,7 @@ our $LBAD_DEFAULT   = undef;
 ## $TDF_MGOOD_DEFAULT
 ##  + default positive meta-field regex for document parsing (tdf only)
 ##  + don't use qr// here, since Storable doesn't like pre-compiled Regexps
-our $TDF_MGOOD_DEFAULT = q/^(?:author|title|basename|collection|flags|textClass|genre)$/;
+our $TDF_MGOOD_DEFAULT = q/^(?:author|pnd|title|basename|collection|flags|textClass|genre)$/;
 
 ## $TDF_MBAD_DEFAULT
 ##  + default negative meta-field regex for document parsing (tdf only)
